@@ -191,57 +191,57 @@ class Foreperson:
             if 'kwargs' in recipe['background']:
                 self.reduction.bkg_kwargs = recipe['background']['kwargs']
 
-            the_boss.metadata['data source']['origin']['experiment date'] = str(datetime.datetime.now().date())
+            self.metadata['data source']['origin']['experiment date'] = str(datetime.datetime.now().date())
         # Populate the setup information
         if 'setup' in keys:
-            if 'dcd normalisation' in the_boss.recipe['setup'].keys():
-                the_boss.reduction.dcd_normalisation = the_boss.recipe['setup']['dcd normalisation']
-                the_boss.data_source.links = {'instrument reference': 'doi:10.1107/S0909049512009272'}
-            if 'sample size' in the_boss.recipe['setup'].keys():
-                the_boss.reduction.sample_size = make_tuple(the_boss.recipe['setup']['sample size'])
+            if 'dcd normalisation' in recipe['setup'].keys():
+                self.reduction.dcd_normalisation = recipe['setup']['dcd normalisation']
+                self.data_source.links = {'instrument reference': 'doi:10.1107/S0909049512009272'}
+            if 'sample size' in recipe['setup'].keys():
+                self.reduction.sample_size = make_tuple(recipe['setup']['sample size'])
                 try:
-                    _ = len(the_boss.reduction.sample_size)
-                    the_boss.reduction.sample_size = ufloat(the_boss.reduction.sample_size[0], the_boss.reduction.sample_size[1])
+                    _ = len(self.reduction.sample_size)
+                    self.reduction.sample_size = ufloat(self.reduction.sample_size[0], self.reduction.sample_size[1])
                 except TypeError:
                     pass
             else:
                 raise ValueError("No sample size given in setup of {}.".format(yaml_file))
-            if 'beam width' in the_boss.recipe['setup'].keys():
-                the_boss.reduction.beam_width = make_tuple(the_boss.recipe['setup']['beam width'])
+            if 'beam width' in recipe['setup'].keys():
+                self.reduction.beam_width = make_tuple(recipe['setup']['beam width'])
                 try:
-                    _ = len(the_boss.reduction.beam_width)
-                    the_boss.reduction.beam_width = ufloat(the_boss.reduction.beam_width[0], the_boss.reduction.beam_width[1])
+                    _ = len(self.reduction.beam_width)
+                    self.reduction.beam_width = ufloat(self.reduction.beam_width[0], self.reduction.beam_width[1])
                 except TypeError:
                     pass
             else:
                 raise ValueError("No beam width given in setup of {}.".format(yaml_file))
-            if 'theta_axis' in the_boss.recipe['setup'].keys():
-                the_boss.experiment.measurement.theta_axis_name = the_boss.recipe['setup']['theta_axis']
-            if 'q axis' in the_boss.recipe['setup'].keys():
-                the_boss.experiment.measurement.q_axis_name = the_boss.recipe['setup']['q axis']
-            if 'transpose' in the_boss.recipe['setup'].keys():
-                the_boss.experiment.measurement.transpose = the_boss.recipe['setup']['transpose']
-                if the_boss.experiment.measurement.transpose:
-                    the_boss.experiment.measurement.qz_dimension = 0
-                    the_boss.experiment.measurement.qxy_dimension = 1
-            if 'pixel_max' in the_boss.recipe['setup'].keys():
-                the_boss.experiment.measurement.pixel_max = the_boss.recipe['setup']['pixel_max']
-            if 'hot_pixel_max' in the_boss.recipe['setup'].keys():
-                the_boss.experiment.measurement.hot_pixel_max = the_boss.recipe['setup']['hot_pixel_max']
+            if 'theta_axis' in recipe['setup'].keys():
+                self.experiment.measurement.theta_axis_name = recipe['setup']['theta_axis']
+            if 'q axis' in recipe['setup'].keys():
+                self.experiment.measurement.q_axis_name = recipe['setup']['q axis']
+            if 'transpose' in recipe['setup'].keys():
+                self.experiment.measurement.transpose = recipe['setup']['transpose']
+                if self.experiment.measurement.transpose:
+                    self.experiment.measurement.qz_dimension = 0
+                    self.experiment.measurement.qxy_dimension = 1
+            if 'pixel_max' in recipe['setup'].keys():
+                self.experiment.measurement.pixel_max = recipe['setup']['pixel_max']
+            if 'hot_pixel_max' in recipe['setup'].keys():
+                self.experiment.measurement.hot_pixel_max = recipe['setup']['hot_pixel_max']
         else:
             raise ValueError("No setup given in {}.".format(yaml_file))
         if 'output_columns' in keys:
-            if the_boss.recipe['output_columns'] == 3:
+            if recipe['output_columns'] == 3:
                 self.data = Data(columns=['Qz / Aa^-1', 'RQz', 'sigma RQz, standard deviation'])
         if 'rebin' in keys:
-            if 'n qvectors' in the_boss.recipe['rebin'].keys():
-                the_boss.data.n_qvectors = the_boss.recipe['rebin']['n qvectors']
-            elif 'min' in the_boss.recipe['rebin'].keys() and 'max' in the_boss.recipe['rebin'].keys() and 'step' in the_boss.recipe['rebin'].keys():
-                the_boss.data.q_min = the_boss.recipe['rebin']['min']
-                the_boss.data.q_max = the_boss.recipe['rebin']['max']
-                the_boss.data.q_step = the_boss.recipe['rebin']['step']
-                if 'shape' in the_boss.recipe['rebin'].keys():
-                    the_boss.data.q_shape = the_boss.recipe['rebin']['shape']
+            if 'n qvectors' in recipe['rebin'].keys():
+                self.data.n_qvectors = recipe['rebin']['n qvectors']
+            elif 'min' in recipe['rebin'].keys() and 'max' in recipe['rebin'].keys() and 'step' in recipe['rebin'].keys():
+                self.data.q_min = recipe['rebin']['min']
+                self.data.q_max = recipe['rebin']['max']
+                self.data.q_step = recipe['rebin']['step']
+                if 'shape' in recipe['rebin'].keys():
+                    self.data.q_shape = recipe['rebin']['shape']
             else:
                 raise ValueError("Please define parameters of rebin in {}.".format(yaml_file))
         else:
